/*
 *      INSTALL.CMD Generic MAC Wrapper Driver Pack - Copryright netlabs.org 2005
 *      Installation for Generic MAC Wrapper Driver - Copyright C.Langanke 2005
 *
 *      Syntax: INSTALL
 *
 *      This program installs the Driver Pack onto an existing installation 
 *      of the Generic MAC Wrapper Driver main package
 *
 */
/* The first comment is used as online help text */

 SIGNAL ON HALT

 TitleLine = STRIP(SUBSTR(SourceLine( 2), 3));
 PARSE VAR TitleLine CmdName'.CMD 'Info
 Title     = Info
 Subtitle  = STRIP(SUBSTR(SourceLine( 3), 3));

 env          = 'OS2ENVIRONMENT';
 TRUE         = (1 = 1);
 FALSE        = (0 = 1);
 CrLf         = '0d0a'x;
 Redirection  = '> NUL 2>&1';
 '@ECHO OFF'

 /* OS/2 Error codes */
 ERROR.NO_ERROR           =   0;
 ERROR.INVALID_FUNCTION   =   1;
 ERROR.FILE_NOT_FOUND     =   2;
 ERROR.PATH_NOT_FOUND     =   3;
 ERROR.ACCESS_DENIED      =   5;
 ERROR.NOT_ENOUGH_MEMORY  =   8;
 ERROR.INVALID_FORMAT     =  11;
 ERROR.INVALID_DATA       =  13;
 ERROR.NO_MORE_FILES      =  18;
 ERROR.WRITE_FAULT        =  29;
 ERROR.READ_FAULT         =  30;
 ERROR.GEN_FAILURE        =  31;
 ERROR.SHARING_VIOLATION  =  32;
 ERROR.INVALID_PARAMETER  =  87;
 ERROR.ENVVAR_NOT_FOUND   = 203;

 GlobalVars = 'Title CmdName CrLf env TRUE FALSE Redirection ERROR.';
 SAY;

 /* eventually show help */
 ARG Parm .
 IF (POS('?', Parm) > 0) THEN
 DO
    rc = ShowHelp();
    EXIT(ERROR.INVALID_PARAMETER);
 END;

 call RxFuncAdd    'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
 call SysLoadFuncs

 /* dafault values */
 GlobalVars = GlobalVars 'CallDir AppName';
 rc = ERROR.NO_ERROR;

 IniAppName    = 'Generic MAC Wrapper Driver';
 IniKeyVersion = 'Version';
 IniKeyPath    = 'Path';

 CallDir  = GetCallDir();
 PARSE VALUE TRANSLATE( VALUE( 'PATH',,env)) WITH '\OS2;' -2 BootDrive +2;

 DO 1

    SAY Title;
    SAY SubTitle;
    SAY;

    /* get INI information of installed package */
    PARSE VALUE SysIni(, IniAppName, IniKeyVersion) WITH InstAppVersion'0'x;
    PARSE VALUE SysIni(, IniAppName, IniKeyPath) WITH InstallDir'0'x;
    InstallScript = InstallDir'\install.cmd'
    IF ((InstAppVersion = 'ERROR:') |,
        (InstallDir = 'ERROR:')     |,
        (\FileExist( InstallScript))) THEN
    DO
       SAY 'error: cannot find genmac installation';
       SAY 'Install main GenMac driver package first!';
       rc = 3;
       LEAVE
    END;

    /* check version of this driver pack */
    AppVersion = ReadVersion();
    IF (AppVersion = '') THEN
    DO
       SAY 'error: cannot detect package version informtion.';
       rc = 2;
       LEAVE
    END;

    /* version must match */
    IF (InstAppVersion \= AppVersion) THEN
    DO
       SAY;
       SAY '  error: the version of this Driver Pack does not match the'
       SAY '         version of the installed GenMac main package!'.
       SAY;
       SAY '  Installed GenMac main package: V'InstAppVersion;
       SAY '             GenMac Driver pack: V'AppVersion;
       SAY;
       SAY '  Install the GenMac main package V'AppVersion 'first.';
       SAY '';
       rc = 2;
       LEAVE
    END;


    /* call the installation program */
    'CALL' InstallDir'\install.cmd' DIRECTORY();

 END;

 EXIT( rc);

/* ------------------------------------------------------------------------- */
HALT:
 SAY 'Abbruch durch Benutzer.';
 EXIT(ERROR.GEN_FAILURE);

/* ------------------------------------------------------------------------- */
ShowHelp: PROCEDURE EXPOSE (GlobalVars)

 /* show title */
 SAY Title;
 SAY;

 PARSE SOURCE . . ThisFile

 /* skip header */
 DO i = 1 TO 3
    rc = LINEIN(ThisFile);
 END;

 /* show help text */
 ThisLine = LINEIN(Thisfile);
 DO WHILE (ThisLine \= ' */')
    SAY SUBSTR(ThisLine, 7);
    ThisLine = LINEIN(Thisfile);
 END;

 /* close file */
 rc = LINEOUT(Thisfile);

 RETURN('');

/* ------------------------------------------------------------------------- */
FileExist: PROCEDURE
 PARSE ARG FileName

 RETURN(STREAM(Filename, 'C', 'QUERY EXISTS') > '');

/* ------------------------------------------------------------------------- */
GetCalldir: PROCEDURE
PARSE SOURCE . . CallName
 CallDir = FILESPEC('Drive', CallName)||FILESPEC('Path', CallName);
 RETURN(LEFT(CallDir, LENGTH(CallDir) - 1));

/* ========================================================================= */
ReadVersion: PROCEDURE EXPOSE (GlobalVars);

 AppVersion = '';
 DescFile   = 'file_id.diz';

 DO 1
    /* read description file */
    IF (STREAM( DescFile, 'C', 'OPEN READ') \= 'READY:') THEN
       LEAVE;

    PARSE VALUE LINEIN( DescFile) WITH '('LitVersion')'.
    IF (LENGTH( LitVersion) \= 5) THEN
       LEAVE;

    PARSE VAR LitVersion . +1 AppVersion;
    AppVersion = TRANSLATE( STRIP( AppVersion));

 END;

 /* cleanup */
 rcx = STREAM( DescFile, 'C', 'CLOSE');
 RETURN( AppVersion);

